Module price

Utility functions for working with prices.

Functions

alias_to_step_size
Round the decimal to the nearest multiple of increment in the direction of zero
is_equal_or_less_agg_than
is_equal_or_more_agg_than
is_less_agg_than
is_more_agg_than
Return true if the first price is more aggressive than the second for the specified direction.
least_agg
less_agg_by
more_agg_by
most_agg
tick_size_round_less_agg